==> go.php?file=BossModChecker1.000.zip: BossModChecker/Localization/localization-frFR.lua <==
﻿if GetLocale() == "frFR" then


function bmclocale()



	bmcattention = "Attention!"
	bmcbmctitle = "Verification des versions de Boss Mods" -- Needs review
	bmcbutbmc = "Vérification des Boss Mods" -- Needs review
	bmcmainbgbm = "En champ de bataille" -- Needs review
	bmcmainbmnotmorethenof = "Vous pouvez envoyer des chuchotements 1 fois toutes les 20s. Attendez un peu" -- Needs review
	bmcmainbossmsort = "Trié par" -- Needs review
	bmcmainbossmsort1 = "boss mod" -- Needs review
	bmcmainbossmsort2 = "nom" -- Needs review
	bmcmainbossmsort3 = "classe" -- Needs review
	bmcmainnobosm = "Pas de Boss Mod trouvé" -- Needs review
	bmcmainnotcheckbosm = "Hors ligne (non vérifié)" -- Needs review
	bmcmainoffline = "Hors-ligne" -- Needs review
	bmcmainonly = "seulement" -- Needs review
	bmcmainrepinf = "envoyer un chuchotement aux raiders qui ont une vieille version de Boss Mod" -- Needs review
	bmcmainrepinf2 = "envoyer un chuchotement aux raiders qui n'ont pas %s, ou en ont une ancienne version" -- Needs review
	bmcmainreportoldbm1 = "Vous avez une ancienne version de %s. Votre version est: %s, la dernière en date est: %s" -- Needs review
	bmcmainreportoldbm2 = "Le vérificateur de Boss Mod n'a trouvé aucun boss mod" -- Needs review
	bmcmainreportoldbm3 = "le raid a été inspecté pour l'installation de %s. Vous n'avez pas cet addon" -- Needs review
	bmcmaintooearlybm = "Pour des résultats précis, vous devriez rester dans le raid pour au moins quelques minutes, tous les Boss Mods n'envoient pas instantanément les données sur leur version" -- Needs review
	bmcsend = "Envoyé(e)"


end

end

==> go.php?file=BossModChecker11.003.zip: BossModChecker/Localization/localization-frFR.lua <==
﻿if GetLocale() == "frFR" then


function bmclocale()



	bmcattention = "Attention!"
	bmcbmctitle = "Verification des versions de Boss Mods" -- Needs review
	bmcbutbmc = "Vérification des Boss Mods" -- Needs review
	bmcmainbgbm = "En champ de bataille" -- Needs review
	bmcmainbmnotmorethenof = "Vous pouvez envoyer des chuchotements 1 fois toutes les 20s. Attendez un peu" -- Needs review
	bmcmainbossmsort = "Trié par" -- Needs review
	bmcmainbossmsort1 = "boss mod" -- Needs review
	bmcmainbossmsort2 = "nom" -- Needs review
	bmcmainbossmsort3 = "classe" -- Needs review
	bmcmainnobosm = "Pas de Boss Mod trouvé" -- Needs review
	bmcmainnotcheckbosm = "Hors ligne (non vérifié)" -- Needs review
	bmcmainoffline = "Hors-ligne" -- Needs review
	bmcmainonly = "seulement" -- Needs review
	bmcmainrepinf = "envoyer un chuchotement aux raiders qui ont une vieille version de Boss Mod" -- Needs review
	bmcmainrepinf2 = "envoyer un chuchotement aux raiders qui n'ont pas %s, ou en ont une ancienne version" -- Needs review
	bmcmainreportoldbm1 = "Vous avez une ancienne version de %s. Votre version est: %s, la dernière en date est: %s" -- Needs review
	bmcmainreportoldbm2 = "Le vérificateur de Boss Mod n'a trouvé aucun boss mod" -- Needs review
	bmcmainreportoldbm3 = "le raid a été inspecté pour l'installation de %s. Vous n'avez pas cet addon" -- Needs review
	bmcmaintooearlybm = "Pour des résultats précis, vous devriez rester dans le raid pour au moins quelques minutes, tous les Boss Mods n'envoient pas instantanément les données sur leur version" -- Needs review
	bmcsend = "Envoyé(e)"

	bmcmainbattlegr1 = "Vallée d'Alterac"
	bmcmainbattlegr2 = "Bassin Arathi"
	bmcmainbattlegr3 = "L'Œil du cyclone"
	bmcmainbattlegr4 = "Île des Conquérants"
	bmcmainbattlegr5 = "Rivage des Anciens"
	bmcmainbattlegr6 = "La bataille de Gilnéas"
	bmcmainbattlegr7 = "Pics-Jumeaux"
	bmcmainbattlegr8 = "Goulet des Chanteguerres"
	
end

end
